'''
Created on Jul 1, 2015

@author: egodolja

'''
'''
import unittest

from unittest.mock import MagicMock
from authorizenet import apicontractsv1
#from controller.ARBCancelSubscriptionController import ARBCancelSubscriptionController
from tests import apitestbase
from authorizenet.apicontrollers import *
import test
'''
'''
class ARBCancelSubscriptionControllerTest(apitestbase.ApiTestBase):

    def test_ARBCancelSubscriptionController(self):
        cancelSubscriptionRequest = apicontractsv1.ARBCancelSubscriptionRequest()
        cancelSubscriptionRequest.merchantAuthentication = self.merchantAuthentication
        cancelSubscriptionRequest.refId = 'Sample'
        cancelSubscriptionRequest.subscriptionId = '2680891'
        
        ctrl = ARBCancelSubscriptionController()

        ctrl.execute = MagicMock(return_value=None)

        ctrl.execute(cancelSubscriptionRequest, apicontractsv1.ARBCancelSubscriptionResponse)
        
        ctrl.execute.assert_called_with(cancelSubscriptionRequest, apicontractsv1.ARBCancelSubscriptionResponse)
        ctrl.execute.assert_any_call(cancelSubscriptionRequest, apicontractsv1.ARBCancelSubscriptionResponse)

'''
'''       
class ARBCreateSubscriptionTest(apitestbase.ApiTestBase):

    def testCreateSubscriptionController(self):
        createSubscriptionRequest = apicontractsv1.ARBCreateSubscriptionRequest()
        createSubscriptionRequest.merchantAuthentication = self.merchantAuthentication
        createSubscriptionRequest.refId = 'Sample'
        createSubscriptionRequest.subscription = self.subscriptionOne
    
        ctrl = ARBCreateSubscriptionController()
        
        ctrl.execute = MagicMock(return_value=None)
        
        createRequest = ctrl.ARBCreateSubscriptionController(createSubscriptionRequest)
        ctrl.execute(createRequest, apicontractsv1.ARBCreateSubscriptionResponse)
        
        ctrl.execute.assert_called_with(createRequest, apicontractsv1.ARBCreateSubscriptionResponse )
        ctrl.execute.assert_any_call(createRequest, apicontractsv1.ARBCreateSubscriptionResponse)

class ARBGetSubscriptionStatusTest(object):
    
    
    def testGetSubscriptionStatusController(self):
        getSubscriptionStatusRequest = apicontractsv1.ARBGetSubscriptionStatusRequest()
        getSubscriptionStatusRequest.merchantAuthentication = self.merchantAuthentication
        getSubscriptionStatusRequest.refId = 'Sample'
        getSubscriptionStatusRequest.subscriptionId = '2680891'
    
        ctrl = ARBGetSubscriptionStatusController()
        
        ctrl.execute = MagicMock(return_value=None)
        
        statusRequest = ctrl.ARBGetSubscriptionStatusController(getSubscriptionStatusRequest)
        ctrl.execute(statusRequest, apicontractsv1.ARBGetSubscriptionStatusResponse)
        
        ctrl.execute.assert_called_with(statusRequest, apicontractsv1.ARBGetSubscriptionStatusResponse)
        ctrl.execute.assert_any_call(statusRequest, apicontractsv1.ARBGetSubscriptionStatusResponse)     
'''
    
 



"""
Created on Nov 4, 2015

@author: krgupta
@updated: William Hinz
"""

from configparser import ConfigParser, Error as ConfigParserError

import os
import logging
import pathlib

logger = logging.getLogger(__name__)

ROOT_DIR = pathlib.Path(__file__).parent.parent  # Should point to the root of the project!


class Helper:

    def __init__(self, property_filename: str):
        self.property_filename = property_filename
        self.property_file_uri = None
        self.parser = None
        self.set_property_file(self.property_filename)
        self.create_parser()

    def set_property_file(self, property_filename: str):
        if property_filename is not None:
            temp_file_uri = pathlib.Path(ROOT_DIR, property_filename)
            if temp_file_uri.is_file():
                self.property_file_uri = temp_file_uri

    def create_parser(self):
        if self.parser is None:
            try:
                self.parser = ConfigParser({"http": "", "https": "", "ftp": ""})
            except ConfigParserError:
                logger.warning("Parser could not be initialized")

        if self.parser is not None:
            try:
                files_successfully_read_in = self.parser.read(self.property_file_uri)
                logger.debug(f'config files successfully read in: {files_successfully_read_in}')
            except ConfigParserError:
                logger.warning("Unable to load the property file")

    def get_property(self, property_name):
        string_value = None
        if self.property_file_uri is not None and self.parser is not None:
            try:
                string_value = self.parser.get("properties", property_name)
            except ConfigParserError:
                logger.debug(f"{property_name} not found\n")

        if string_value is None:
            string_value = os.getenv(property_name)
        return string_value



from authorizenot.constants import constants
from decimal import *
import logging
import datetime
import unittest
from authorizenot import apicontractsv1
from authorizenot.utility import Helper


class TestCreateTransactionUnitTest(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.helper = Helper('anet_python_sdk_properties.ini')

    def testPyxbDeserializationElementAtMid(self):
        self.__PyxbDeserialization(False)
      
    def testPyxbDeserializationElementAtLast(self):
        self.__PyxbDeserialization(True)
      
    def testPyxbDeserializationGoodXML(self):
        self.__PyxbDeserialization()
                          
    def __PyxbDeserialization(self, last_element: bool = None):
        logging_filename = self.helper.get_property(constants.propertiesloggingfilename)
        logging_level = self.helper.get_property(constants.propertiesexecutionlogginglevel)
        
        deserializedObject = None
        deserializedBadObject = None
        
        if logging_filename is None:
            logging_filename = constants.defaultLogFileName
        if logging_level is None:
            logging_level = constants.defaultLoggingLevel
            
        logging.basicConfig(filename=logging_filename, level=logging_level, format=constants.defaultlogformat)
          
        merchantAuth = apicontractsv1.merchantAuthenticationType()
        merchantAuth.name = "unknown"
        merchantAuth.transactionKey = "anon"
    
        creditCard = apicontractsv1.creditCardType()
        creditCard.cardNumber = "4111111111111111"
        creditCard.expirationDate = "2020-12"
    
        payment = apicontractsv1.paymentType()
        payment.creditCard = creditCard
    
        transactionrequest = apicontractsv1.transactionRequestType()
        transactionrequest.transactionType = "authCaptureTransaction"
        transactionrequest.amount = Decimal( 6.99)
        transactionrequest.payment = payment
    
        createtransactionrequest = apicontractsv1.createTransactionRequest()
        createtransactionrequest.merchantAuthentication = merchantAuth
        createtransactionrequest.transactionRequest = transactionrequest
        createtransactionrequest.refId = "MerchantID-0001"

        logging.debug("Request: %s " % datetime.datetime.now())
        logging.debug("       : %s " % createtransactionrequest)
        
        try:    
            xmlRequest = createtransactionrequest.toxml(encoding=constants.xml_encoding, element_name='createTransactionRequest')
            xmlRequest = xmlRequest.replace(constants.nsNamespace1, '')
            xmlRequest = xmlRequest.replace(constants.nsNamespace2, '')
            ##print ("xmlRequest %s " %xmlRequest)
            logging.debug( "Xml Request: %s" % xmlRequest)
        except Exception as ex:
            logging.debug( "Xml Exception: %s" % ex)
        
        badXmlElement = None
        
        if (last_element == None):
            try:
                deserializedObject = apicontractsv1.CreateFromDocument(xmlRequest)           
                self.assertIsNotNone(deserializedObject, "Null deserializedObject ")
                
                if type(createtransactionrequest) == type(deserializedObject):
                    ##print (" for good xml objects are equal")
                    logging.debug( "createtransactionrequest object is equal to deserializedObject") 
                else:
                    ##print ("for good xml some error: objects are NOT equal" )
                    logging.debug( "createtransactionrequest object is NOT equal to deserializedObject") 
                    
                deseriaziedObjectXmlRequest = deserializedObject.toxml(encoding=constants.xml_encoding, element_name='deserializedObject')
                deseriaziedObjectXmlRequest = deseriaziedObjectXmlRequest.replace(constants.nsNamespace1, '')
                deseriaziedObjectXmlRequest = deseriaziedObjectXmlRequest.replace(constants.nsNamespace2, '')
                logging.debug( "Good Dom Request: %s " % deseriaziedObjectXmlRequest ) 
                ##print ( "Good De-serialized XML: %s \n" % deseriaziedObjectXmlRequest )
            except Exception as ex:
                logging.error( 'Create Document Exception: %s, %s', type(ex), ex.args )      
        else:
            if (last_element == False):
                try:
                    splitString = "<amount>"
                    lines = xmlRequest.split( splitString)
                    badXmlElement = "<badElement>BadElement</badElement>"
                    badXmlRequest = lines[0] + badXmlElement + splitString + lines[1]
                    logging.debug( "Bad XmlRequest: %s" % badXmlRequest)
                    ##print ("ElementInMidXML Request:  %s \n" %badXmlRequest)
                except Exception as ex:
                    ##print ("ElementInMidXML can not be inserted: %s, %s",type(ex), ex.args)
                    logging.debug( "ElementInMidXML can not be inserted: %s, %s" ,type(ex), ex.args)             
            if (last_element == True):
                try:    
                    splitStringAtLast = "</payment>"
                    lines = xmlRequest.split( splitStringAtLast)
                    badXmlElementAtLast = "<badElementAtLast>BadElementAtLast</badElementAtLast>"
                    badXmlRequest = lines[0] + badXmlElementAtLast + splitStringAtLast + lines[1]
                    logging.debug( "Bad XmlRequest at Last: %s" % badXmlRequest)
                    ##print ("ElementAtLastXML Request: %s \n" %badXmlRequest)
                except Exception as ex:
                    ##print ("ElementAtLastXML can not be inserted: %s, %s",type(ex), ex.args)  
                    logging.debug("ElementAtLastXML can not be inserted: %s, %s",type(ex), ex.args)           
            try:     
                deserializedBadObject = apicontractsv1.CreateFromDocument(badXmlRequest)           
                self.assertIsNotNone(deserializedBadObject, "Null deserializedObject ")
                badDomXml = deserializedBadObject.toxml(encoding=constants.xml_encoding, element_name='deserializedBadObject')
                badDomXml = badDomXml.replace(constants.nsNamespace1, '')
                badDomXml = badDomXml.replace(constants.nsNamespace2, '')
                logging.debug( "Bad Dom Request: %s " % badDomXml ) 
                ##print ("Bad Dom De-serialized: %s \n" %badDomXml)
            except Exception as ex:
                logging.error( 'Create Document Exception: %s, %s', type(ex), ex.args )
                ##print ("Exception while de-serializing bad dom: %s, %s",type(ex), ex.args)


class TestCustomerProfile(unittest.TestCase):

    @classmethod
    def setUpClass(cls):
        cls.helper = Helper('anet_python_sdk_properties.ini')

    def testGetCustomerProfile(self):    
        logging_filename = self.helper.get_property(constants.propertiesloggingfilename)
        logging_level = self.helper.get_property(constants.propertiesexecutionlogginglevel)
        logging.basicConfig(filename=logging_filename, level=logging_level, format=constants.defaultlogformat)
          
        merchantAuth = apicontractsv1.merchantAuthenticationType()
        merchantAuth.name = "unknown"
        merchantAuth.transactionKey = "anon"
        
        getCustomerProfileRequest = apicontractsv1.getCustomerProfileRequest() 
        getCustomerProfileRequest.merchantAuthentication = merchantAuth 
        getCustomerProfileRequest.customerProfileId = '36152115'   
        getCustomerProfileRequest.abc = 'aaaaaaaa' #extra property not in getCustomerProfileRequest object
        
        logging.debug("Request: %s " % datetime.datetime.now())
        logging.debug("       : %s " % getCustomerProfileRequest)
        
        try:    
            '''serialzing object to XML '''
            xmlRequest = getCustomerProfileRequest.toxml(encoding=constants.xml_encoding, element_name='getCustomerProfileRequest')
            xmlRequest = xmlRequest.replace(constants.nsNamespace1, b'')
            xmlRequest = xmlRequest.replace(constants.nsNamespace2, b'')
            logging.debug( "Xml Request: %s" % xmlRequest)
            #print( "Xml Request: %s" % xmlRequest)
        except Exception as ex:
            logging.debug( "Xml Exception: %s" % ex)    
            
        try:
            '''deserialize XML to object '''    
            deserializedObject = None
            deserializedObject = apicontractsv1.CreateFromDocument(xmlRequest)           
            self.assertIsNotNone(deserializedObject, "Null deserializedObject ")
            
            if type(getCustomerProfileRequest) == type(deserializedObject):
                #print ("objects are equal")
                logging.debug( "createtransactionrequest object is equal to deserializedObject") 
            else:
                #print ("some error: objects are NOT equal" )
                logging.debug( "createtransactionrequest object is NOT equal to deserializedObject") 
            
            deseriaziedObjectXmlRequest = deserializedObject.toxml(encoding=constants.xml_encoding, element_name='deserializedObject')
            deseriaziedObjectXmlRequest = deseriaziedObjectXmlRequest.replace(constants.nsNamespace1, '')
            deseriaziedObjectXmlRequest = deseriaziedObjectXmlRequest.replace(constants.nsNamespace2, '')
            logging.debug( "Good Dom Request: %s " % deseriaziedObjectXmlRequest )
            #print( "Good Dom Request: %s " % deseriaziedObjectXmlRequest )
            #print("de-serialized successfully. GOOD CASE COMPLETE  \n ")
        except Exception as ex:
            
            logging.error( 'Create Document Exception: %s, %s', type(ex), ex.args )
        
        self.assertEqual(type(getCustomerProfileRequest), type(deserializedObject), "deseriaziedObject does not match original object")
        
        try:
            #print("starting with element in mid")
            newxml = '<?xml version="1.0" encoding="utf-8"?><getCustomerProfileRequest xmlns="AnetApi/xml/v1/schema/AnetApiSchema.xsd"><merchantAuthentication><name>unknown</name><transactionKey>anon</transactionKey></merchantAuthentication><kriti>11Jan</kriti><customerProfileId>36152115</customerProfileId></getCustomerProfileRequest>'
            
            #print ("newxml: %s" %newxml)
            DEserializedNEWObject = apicontractsv1.CreateFromDocument(newxml)           
            self.assertIsNotNone(DEserializedNEWObject, "Null deserializedObject ")
            
            
            DEseriaziedNEWObjectXmlRequest = DEserializedNEWObject.toxml(encoding=constants.xml_encoding, element_name='deserializedObject')
            DEseriaziedNEWObjectXmlRequest = DEseriaziedNEWObjectXmlRequest.replace(constants.nsNamespace1, '')
            DEseriaziedNEWObjectXmlRequest = DEseriaziedNEWObjectXmlRequest.replace(constants.nsNamespace2, '')
            logging.debug( "Good Dom Request: %s " % DEseriaziedNEWObjectXmlRequest )
            #print( " DEseriaziedNEWObjectXmlRequest Request: %s " % DEseriaziedNEWObjectXmlRequest )
            #print("de-serialized successfully")
            #print("FINISHED element in mid \n ")
        except Exception as ex:    
            #print("DEseriaziedNEWObjectXmlRequest is NOT DESerialized")
            logging.error( 'Create Document Exception: %s, %s', type(ex), ex.args )
            
            
        try:
            #print("starting with element at last")
            newxmlATLAst = '<?xml version="1.0" encoding="utf-8"?><getCustomerProfileRequest xmlns="AnetApi/xml/v1/schema/AnetApiSchema.xsd"><merchantAuthentication><name>unknown</name><transactionKey>anon</transactionKey></merchantAuthentication><customerProfileId>36152115</customerProfileId><gupta>11Jan</gupta></getCustomerProfileRequest>'
            #print ("newxmlATLAst: %s" %newxmlATLAst)
            DEserializedNEWObject = apicontractsv1.CreateFromDocument(newxmlATLAst)           
            self.assertIsNotNone(DEserializedNEWObject, "Null deserializedObject ")
            DEseriaziedNEWObjectXmlRequest = DEserializedNEWObject.toxml(encoding=constants.xml_encoding, element_name='deserializedObject')
            DEseriaziedNEWObjectXmlRequest = DEseriaziedNEWObjectXmlRequest.replace(constants.nsNamespace1, '')
            DEseriaziedNEWObjectXmlRequest = DEseriaziedNEWObjectXmlRequest.replace(constants.nsNamespace2, '')
            logging.debug( "Good Dom Request: %s " % DEseriaziedNEWObjectXmlRequest )
            #print( " DEseriaziedNEWATLASTObjectXmlRequest Request: %s " % DEseriaziedNEWObjectXmlRequest )
            #print("de-serialized successfully")
            #print("Finished element at last \n " )
        except Exception as ex:    
            #print("DEseriaziedNEWATLASTObjectXmlRequest is NOT DESerialized")
            logging.error( 'Create Document Exception: %s, %s', type(ex), ex.args )    


if __name__ == '__main__':
    unittest.main()  



'''
Created on Nov 1, 2015

@author: krgupta
@updated: William Hinz
'''
import abc
import logging
import pyxb
import xml.dom.minidom
import requests
from lxml import objectify

from authorizenot.constants import constants
from authorizenot import apicontractsv1
from authorizenot.utility import Helper

'''
from authorizenet.apicontractsv1 import merchantAuthenticationType
from authorizenet.apicontractsv1 import ANetApiRequest
from authorizenet.apicontractsv1 import ANetApiResponse
'''

anetLogger = logging.getLogger(constants.defaultLoggerName)
anetLogger.addHandler(logging.NullHandler())
logging.getLogger('pyxb.binding.content').addHandler(logging.NullHandler())


class APIOperationBaseInterface(abc.ABC):
    
    @abc.abstractmethod
    def execute(self):
        """
        Makes a http-post call.
        Uses request xml and response class type to check that the response was of correct type
        """
        pass

    @abc.abstractmethod
    def getresponseclass(self):
        """ Returns the response class """
        pass
    
    @abc.abstractmethod
    def getrequesttype(self):
        """ Returns the request class """
        pass
    
    @abc.abstractmethod
    def getresponse(self):
        """ Returns the de-serialized response """
        pass

    @abc.abstractmethod
    def getresultcode(self):
        """ Returns the result code from the response """
        pass
    
    @abc.abstractmethod
    def getmessagetype(self):
        """ Returns the message type enum from the response """
        pass

    @abc.abstractmethod
    def afterexecute(self):
        """ Returns the message received from binding after processing request """
        pass

    @abc.abstractmethod
    def beforeexecute(self):
        """ TODO """
        pass


class APIOperationBase(APIOperationBaseInterface, abc.ABC):

    __merchantauthentication = 'null'
    __environment = 'null'
    __initialized = 'null'

    @staticmethod
    def __classinitialized():
        return APIOperationBase.__initialized

    def __init__(self, api_request):
        super().__init__()
        self.helper = Helper('anet_python_sdk_properties.ini')
        self._httpResponse = None
        self._request = None
        self._response = None
        # objectify variables
        self._responseXML = None
        self._reponseObject = None
        self._mainObject = None

        if api_request is None:
            raise ValueError('Input request cannot be null')

        self._request = api_request
        APIOperationBase.__environment = constants.SANDBOX
        APIOperationBase.__merchantauthentication = apicontractsv1.merchantAuthenticationType()
        self.validate()

    @abc.abstractmethod
    def validaterequest(self):
        return
    
    def validate(self):
        anet_api_request = self._getrequest()
        self.validateandsetmerchantauthentication()       
        self.validaterequest()

    def setClientId(self):
        self._request.clientId = constants.clientId

    def _getrequest(self):
        return self._request 
     
    def buildrequest(self):
        anetLogger.debug('building request..')
        
        xmlRequest = self._request.toxml(encoding=constants.xml_encoding, element_name=self.getrequesttype())
        #remove namespaces that toxml() generates
        xmlRequest = xmlRequest.replace(constants.nsNamespace1, b'')
        xmlRequest = xmlRequest.replace(constants.nsNamespace2, b'')

        return xmlRequest
    
    def getprettyxmlrequest(self):
        xmlRequest = self.buildrequest()
        requestDom = xml.dom.minidom.parseString(xmlRequest)
        anetLogger.debug('Request is: %s' % requestDom.toprettyxml())

        return requestDom
    
    def execute(self):
        anetLogger.debug('Executing http post to url: %s', self.__environment)
        self.beforeexecute()
        proxy_dictionary = {'http': self.helper.get_property("http_proxy"),
                            'https': self.helper.get_property("https_proxy"),
                            'ftp': self.helper.get_property("ftp")}

        # requests is http request
        try:
            self.setClientId()
            xmlRequest = self.buildrequest()
            self._httpResponse = requests.post(self.__environment, data=xmlRequest, headers=constants.headers, proxies=proxy_dictionary)
        except Exception as httpException:
            anetLogger.error('Error retrieving http response from: %s for request: %s', self.__environment, self.getprettyxmlrequest())
            anetLogger.error('Exception: %s, %s', type(httpException), httpException.args)

        if self._httpResponse:
            self._httpResponse.encoding = constants.response_encoding
            self._httpResponse = self._httpResponse.text[3:]  # strip BOM
            self.afterexecute()

            try:
                self._response = apicontractsv1.CreateFromDocument(self._httpResponse) 
                # objectify code
                xmlResponse = self._response.toxml(encoding=constants.xml_encoding, element_name=self.getrequesttype())
                xmlResponse = xmlResponse.replace(constants.nsNamespace1, b'')
                xmlResponse = xmlResponse.replace(constants.nsNamespace2, b'')
                self._mainObject = objectify.fromstring(xmlResponse)
            except Exception as objectifyexception:
                anetLogger.error( 'Create Document Exception: %s, %s', type(objectifyexception), objectifyexception.args )
                responseString = self._httpResponse
                # removing encoding attribute as objectify fails if it is present
                responseString = responseString.replace('encoding=\"utf-8\"', '')
                self._mainObject = objectify.fromstring(responseString) 
            else:
                if type(self.getresponseclass()) is not type(self._mainObject):
                    if self._response.messages.resultCode == "Error":
                        anetLogger.debug("Response error")
                    domResponse = xml.dom.minidom.parseString(self._httpResponse.encode('utf-8'))
                    anetLogger.debug('Received response: %s' % domResponse.toprettyxml(encoding='utf-8'))
                else:
                    # Need to handle ErrorResponse
                    anetLogger.debug('Error retrieving response for request: %s' % self._request)
        else:
            anetLogger.debug("Did not receive http response")

    def getresponse(self):
        # return self._response  # pyxb object
        return self._mainObject  # objectify object
    
    def getresultcode(self):
        resultcode = 'null'
        if self._response:
            resultcode = self._response.resultCode
        return resultcode
    
    def getmessagetype(self):
        message = 'null'
        if self._response:
            message = self._response.message
        return message
    
    def afterexecute(self):
        pass
    
    def beforeexecute(self):
        pass

    def getmerchantauthentication(self):
        return self.__merchantauthentication
    
    @staticmethod
    def setmerchantauthentication(merchant_authentication):
        APIOperationBase.__merchantauthentication = merchant_authentication

    def validateandsetmerchantauthentication(self):
        anetapirequest = apicontractsv1.ANetApiRequest()
        if anetapirequest.merchantAuthentication == 'null':
            if self.getmerchantauthentication() != 'null':
                anetapirequest.merchantAuthentication = self.getmerchantauthentication()
            else:
                raise ValueError('Merchant Authentication can not be None')

    @staticmethod
    def getenvironment():
        return APIOperationBase.__environment

    @staticmethod
    def setenvironment(userenvironment):
        APIOperationBase.__environment = userenvironment



"""
Created on Nov 16, 2015

@author: krgupta
@updated: William Hinz
"""
from authorizenot.apicontrollers import *
from decimal import *
import random
import unittest
from tests import apitestbase


class TestReadProperty(apitestbase.ApiTestBase):

    def testPropertyFromFile(self):
        login = self.helper.get_property("api.login.id")
        if login is None:
            login = self.helper.get_property("api_login_id")
        transactionkey = self.helper.get_property("transaction.key")
        if transactionkey is None:
            transactionkey = self.helper.get_property("transaction_key")
        self.assertIsNotNone(login)
        self.assertIsNotNone(transactionkey)


class TestTransactionReportingUnitTest(apitestbase.ApiTestBase):

    def testchargeCreditCard(self):
        creditCard = apicontractsv1.creditCardType()
        creditCard.cardNumber = "4111111111111111"
        creditCard.expirationDate = "2100-12"
        payment = apicontractsv1.paymentType()
        payment.creditCard = creditCard
        transactionrequest = apicontractsv1.transactionRequestType()
        transactionrequest.transactionType = "authCaptureTransaction"
        transactionrequest.amount = Decimal(str(round(random.random()*100, 2)))
        transactionrequest.payment = payment
        createtransactionrequest = apicontractsv1.createTransactionRequest()
        createtransactionrequest.merchantAuthentication = self.merchantAuthentication
        createtransactionrequest.refId = "MerchantID-0001"
        createtransactionrequest.transactionRequest = transactionrequest
        createtransactioncontroller = createTransactionController(createtransactionrequest)
        createtransactioncontroller.execute()
        response = createtransactioncontroller.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'transactionResponse') == True:
            if hasattr(response.transactionResponse, 'transId') == True:
                createdTransactionId = response.transactionResponse.transId
        return str(createdTransactionId)
                  
    def testgetTransactionDetails(self):    
        gettransactiondetailsrequest = apicontractsv1.getTransactionDetailsRequest()
        gettransactiondetailsrequest.merchantAuthentication = self.merchantAuthentication
        transactionID = self.testchargeCreditCard()
        gettransactiondetailsrequest.transId = transactionID #update valid transaction id
        gettransactiondetailscontroller = getTransactionDetailsController(gettransactiondetailsrequest)
        gettransactiondetailscontroller.execute()
        response =  gettransactiondetailscontroller.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)


class TestRecurringBillingTest(apitestbase.ApiTestBase):

    def testCreateSubscription(self):
        createsubscriptionrequest = apicontractsv1.ARBCreateSubscriptionRequest()
        createsubscriptionrequest.merchantAuthentication = self.merchantAuthentication
        createsubscriptionrequest.refId = 'Sample'
        createsubscriptionrequest.subscription = self.subscriptionOne
        arbcreatesubscriptioncontroller = ARBCreateSubscriptionController(createsubscriptionrequest)
        arbcreatesubscriptioncontroller.execute()
        response = arbcreatesubscriptioncontroller.getresponse()
        createdSubscriptionId = None
        if hasattr(response, 'messages') and hasattr(response.messages, 'resultCode'):
            self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'subscriptionId'):
            createdSubscriptionId = response.subscriptionId
        return str(createdSubscriptionId)

    def testGetSubscription(self):
        getSubscription = apicontractsv1.ARBGetSubscriptionRequest()
        getSubscription.merchantAuthentication = self.merchantAuthentication
        subscriptionID = self.testCreateSubscription()
        getSubscription.subscriptionId = subscriptionID #update valid subscription id
        getSubscriptionController = ARBGetSubscriptionController(getSubscription)
        getSubscriptionController.execute()
        response = getSubscriptionController.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
       
    def testCancelSubscription(self):   
        cancelsubscriptionrequest = apicontractsv1.ARBCancelSubscriptionRequest()
        cancelsubscriptionrequest.merchantAuthentication = self.merchantAuthentication
        cancelsubscriptionrequest.refId = 'Sample'
        subscriptionID = self.testCreateSubscription()
        cancelsubscriptionrequest.subscriptionId = subscriptionID  # input valid subscriptionId
        cancelsubscriptioncontroller = ARBCancelSubscriptionController(cancelsubscriptionrequest)
        cancelsubscriptioncontroller.execute()  
        response = cancelsubscriptioncontroller.getresponse()
        if hasattr(response, 'messages'):
            if hasattr(response.messages, 'resultCode'):
                self.assertEqual('Ok', response.messages.resultCode)


class TestPaymentTransactionUnitTest(apitestbase.ApiTestBase):

    def testAuthCaptureTransaction(self):  
        transaction_request_type = apicontractsv1.transactionRequestType()
        transaction_request_type.transactionType = "authCaptureTransaction"
        transaction_request_type.amount = self.amount
        transaction_request_type.payment = self.payment
        transaction_request_type.order = self.order
        transaction_request_type.customer = self.customerData
        transaction_request_type.billTo = self.billTo
        create_transaction_request = apicontractsv1.createTransactionRequest()
        create_transaction_request.merchantAuthentication = self.merchantAuthentication
        create_transaction_request.refId = self.ref_id
        create_transaction_request.transactionRequest = transaction_request_type
        create_transaction_controller = createTransactionController(create_transaction_request)
        create_transaction_controller.execute()
        response = create_transaction_controller.getresponse()
        if hasattr(response, 'messages') and hasattr(response.messages, 'resultCode'):
            self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'transactionResponse'):
            self.assertIsNotNone(response.transactionResponse)
            if hasattr(response.transactionResponse, 'transId'):
                self.assertIsNotNone(response.transactionResponse.transId)
               
    def testAuthOnlyContinueTransaction(self):      
        transactionrequesttype = apicontractsv1.transactionRequestType()
        transactionrequesttype.transactionType = "authCaptureTransaction"
        transactionrequesttype.amount = self.amount
        transactionrequesttype.payment = self.payment
        transactionrequesttype.order = self.order
        transactionrequesttype.customer = self.customerData
        transactionrequesttype.billTo = self.billTo
        createtransactionrequest = apicontractsv1.createTransactionRequest()
        createtransactionrequest.merchantAuthentication = self.merchantAuthentication
        createtransactionrequest.refId = self.ref_id
        createtransactionrequest.transactionRequest = transactionrequesttype
        createtransactioncontroller = createTransactionController(createtransactionrequest)
        createtransactioncontroller.execute()
        response = createtransactioncontroller.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'transactionResponse') == True:
            self.assertIsNotNone(response.transactionResponse)
            if hasattr(response.transactionResponse, 'transId') == True:    
                self.assertIsNotNone(response.transactionResponse.transId)
                  
class test_CustomerProfile(apitestbase.ApiTestBase):
    def testCreateCustomerProfile(self):
        createdCustomerProfileID = None
        createCustomerProfile = apicontractsv1.createCustomerProfileRequest()
        createCustomerProfile.merchantAuthentication = self.merchantAuthentication
        randomInt = random.randint(0, 10000)
        createCustomerProfile.profile = apicontractsv1.customerProfileType()
        createCustomerProfile.profile.merchantCustomerId = 'jdoe%s' % randomInt
        createCustomerProfile.profile.description = 'John Doe%s' % randomInt
        createCustomerProfile.profile.email = 'jdoe%s@mail.com' % randomInt
        controller = createCustomerProfileController(createCustomerProfile)
        controller.execute()
        response = controller.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'customerProfileId') == True: 
            createdCustomerProfileID = response.customerProfileId
        return str(createdCustomerProfileID)
             
    def testGetCustomerProfile(self):
        getCustomerProfile = apicontractsv1.getCustomerProfileRequest()
        getCustomerProfile.merchantAuthentication = self.merchantAuthentication
          
        CustomerProfileID = self.testCreateCustomerProfile()   
        getCustomerProfile.customerProfileId = CustomerProfileID 
        controller = getCustomerProfileController(getCustomerProfile)
        controller.execute()
        response = controller.getresponse()
        self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)

    def testCreateAndGetCustomerShippingAddress(self):
        officeAddress = apicontractsv1.customerAddressType();
        officeAddress.firstName = "John"
        officeAddress.lastName = "Doe"
        officeAddress.address = "123 Main St."
        officeAddress.city = "Bellevue"
        officeAddress.state = "WA"
        officeAddress.zip = "98004"
        officeAddress.country = "USA"
        officeAddress.phoneNumber = "000-000-0000"
        shippingAddressRequest = apicontractsv1.createCustomerShippingAddressRequest()
        shippingAddressRequest.address = officeAddress
        CustomerProfileID = self.testCreateCustomerProfile() 
        shippingAddressRequest.customerProfileId = CustomerProfileID
        shippingAddressRequest.merchantAuthentication = self.merchantAuthentication
        controller = createCustomerShippingAddressController(shippingAddressRequest)
        controller.execute()
        response = controller.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
        if hasattr(response, 'customerAddressId') == True: 
            createdShippingAddressId = str(response.customerAddressId)
        #return str(createdShippingAddressId)
        
    #def testGetCustomerShippingAddress(self):
        getShippingAddress = apicontractsv1.getCustomerShippingAddressRequest()
        getShippingAddress.merchantAuthentication = self.merchantAuthentication
         
         
        getShippingAddress.customerProfileId = CustomerProfileID
        getShippingAddress.customerAddressId = createdShippingAddressId
        
        getShippingAddressController = getCustomerShippingAddressController(getShippingAddress)
        getShippingAddressController.execute()
        response = getShippingAddressController.getresponse()
        if hasattr(response, 'messages') == True:
            if hasattr(response.messages, 'resultCode') == True:
                self.assertEqual('Ok', response.messages.resultCode)
            
'''    
class test_ProductionURL(apitestbase.ApiTestBase):  
    #Tests will run only with production credentials
    
          
    def testGetSettledBatchList(self):
        settledBatchListRequest = apicontractsv1.getSettledBatchListRequest() 
        settledBatchListRequest.merchantAuthentication = self.merchantAuthentication
        settledBatchListController = getSettledBatchListController(settledBatchListRequest)
        customEndpoint = constants.PRODUCTION 
        apicontrollersbase.APIOperationBase.setenvironment(customEndpoint)
        settledBatchListController.execute() 
        response = settledBatchListController.getresponse() 
        self.assertEqual('Ok', response.messages.resultCode) 
    
    def testGetListofSubscriptions(self):    
        sorting = apicontractsv1.ARBGetSubscriptionListSorting()
        sorting.orderBy = apicontractsv1.ARBGetSubscriptionListOrderFieldEnum.id
        sorting.orderDescending = "false"
        paging = apicontractsv1.Paging()
        paging.limit = 1000
        paging.offset = 1
        GetListofSubscriptionRequest = apicontractsv1.ARBGetSubscriptionListRequest()
        GetListofSubscriptionRequest.merchantAuthentication = self.merchantAuthentication
        GetListofSubscriptionRequest.refId = "Sample"
        GetListofSubscriptionRequest.searchType = apicontractsv1.ARBGetSubscriptionListSearchTypeEnum.subscriptionInactive
        GetListofSubscriptionRequest.sorting = sorting
        GetListofSubscriptionRequest.paging = paging
        arbgetsubscriptionlistcontroller = ARBGetSubscriptionListController(GetListofSubscriptionRequest)
        customEndpoint = constants.PRODUCTION 
        apicontrollersbase.APIOperationBase.setenvironment(customEndpoint)
        arbgetsubscriptionlistcontroller.execute()
        response = arbgetsubscriptionlistcontroller.getresponse()
        self.assertEqual('Ok', response.messages.resultCode) 
'''        
if __name__ =='__main__':
    unittest.main()  
